<?php
/*
Plugin Name: Front Page Excluded Categories
Version: 1.2
Plugin URI: http://geekularity.com/fp-excluded-categories-plugin-for-wordpress/
Description: This version uses a comma separated list of *excluded* category ids. 
Author: Sean O'Steen, Tony Lopes
Author URI: http://geekularity.com/, http://www.tonylopes.net
*/ 

function fpe_where($where) {
	// Change the $cats_to_exclude string to the category id you do not want to appear on the front page.
	// Example:  $cats_to_exclude = '1, 2, 3, 4';
	$opt_name = 'fpe_categories';    
   	$cats_to_exclude = get_option($opt_name);
	global $wpdb, $wp_query;

	if (! $wp_query->is_home || strlen($cats_to_exclude) == 0) {
		return $where;
	}

	if (empty($wpdb->term_relationships))
	{
		$where .= " AND $wpdb->post2cat.category_id NOT IN (" . $cats_to_exclude . ")";
	}
	else
	{
		$where .= " AND $wpdb->term_taxonomy.term_id NOT IN (" . $cats_to_exclude . ")";
	}
	return $where;
}

function fpe_join($join) {
  	global $wpdb, $wp_query;
 
	if (!$wp_query->is_home) {
		return $join;
  	}
	if (empty($wpdb->term_relationships))
	{
		$join .= " LEFT JOIN $wpdb->post2cat ON $wpdb->post2cat.post_id = $wpdb->posts.ID ";
	}
	else
	{
		if (!preg_match("/$wpdb->term_relationships/i",$join)) 
		{
			$join .=" LEFT JOIN $wpdb->term_relationships ON ($wpdb->posts.ID = $wpdb->term_relationships.object_id) ";
		}
	    if (!preg_match("/$wpdb->term_taxonomy/i",$join)) 
		{
			$join .=" LEFT JOIN $wpdb->term_taxonomy ON $wpdb->term_taxonomy.term_taxonomy_id = $wpdb->term_relationships.term_taxonomy_id";
		}
	}
	return $join;
}

function fpe_distinct($distinct) {
	global  $wp_query;

	if (! $wp_query->is_home ) {
		return $distinct;
	}
	return "distinct";
}

add_filter('posts_join', 'fpe_join');
add_filter('posts_where', 'fpe_where');
add_filter('posts_distinct', 'fpe_distinct');
add_action('admin_menu', 'fpe_plugin_menu');

function fpe_plugin_menu() {
  add_options_page('Front Page Excluded Plugin Options', 'Front Page Excluded Plugin', 8, 'fpe-plugin', 'fpe_plugin_options');
}


// mt_options_page() displays the page content for the Test Options submenu
function fpe_plugin_options() {

    // variables for the field and option names 
    $opt_name = 'fpe_categories';    
    $hidden_field_name = 'fpe_submit_hidden';
    $data_field_name = 'fpe_categories';

    // Read in existing option value from database
    $opt_val = get_option( $opt_name );

    // See if the user has posted us some information
    // If they did, this hidden field will be set to 'Y'
    if( $_POST[ $hidden_field_name ] == 'Y' ) {
        // Read their posted value
        $opt_val = $_POST[ $data_field_name ];

        // Save the posted value in the database
        update_option( $opt_name, $opt_val );

        // Put an options updated message on the screen

?>
<div class="updated"><p><strong><?php _e('Options saved.', 'mt_trans_domain' ); ?></strong></p></div>
<?php

    }

    // Now display the options editing screen

    echo '<div class="wrap">';

    // header

    echo "<h2>" . __( 'Front Page Excluded Plugin Options', 'fpe_trans_domain' ) . "</h2>";

    // options form
    
    ?>

<form name="form1" method="post" action="<?php echo str_replace( '%7E', '~', $_SERVER['REQUEST_URI']); ?>">
<input type="hidden" name="<?php echo $hidden_field_name; ?>" value="Y">

<p><?php _e("Excluded Categories Ids separated by commas(,): ", 'fpe_trans_domain' ); ?> 
<input type="text" name="<?php echo $data_field_name; ?>" value="<?php echo $opt_val; ?>" size="30">
</p><hr />

<p class="submit">
<input type="submit" name="Submit" value="<?php _e('Update Options', 'mt_trans_domain' ) ?>" />
</p>

</form>
</div>

<?php
 
}


?>